# frozen_string_literal: true

desc "Restart application"
task :restart do
  in_path(fetch(:current_path)) do
    command %(mkdir -p tmp/)
    command %(touch tmp/restart.txt)
  end
end

desc "Checks out the selected release tag"
task :checkout_release do
  comment "Checking out release \"#{fetch :tag}\""
  command %(git clone -b "#{fetch :tag}" --depth 1 "#{fetch :repository}" .)
end

desc "Uses an RVM envionment"
task :rvm_use do
  command "rvm use \"ruby-#{fetch :rvm_ruby_version}\""
end

desc "Link shared directories."
task :link_shared_dirs do
  # Must be set after :stage is set
  set :shared_files, fetch(:shared_files, []).push(
    "config/environments/#{fetch :stage}.rb"
  )

  comment "Shared directories: #{(fetch :shared_dirs).join("\n")}"
  invoke :'deploy:link_shared_paths'
end

desc "Open the newly deployed server in the browser (for macOS)."
task :open_browser do
  run(:local) do
    command "open https://#{fetch :domain}"
  end
end
