# frozen_string_literal: true

module Groundskeeper
  # Class to execute commands for other classes
  class Executable
    attr_reader :command

    @verbose = false

    class << self
      attr_writer :verbose
    end

    class << self
      attr_reader :verbose
    end

    def initialize(command)
      if `which #{command}`.empty?
        raise "#{command} not found, is it installed on your PATH?"
      end

      @command = command
    end

    def execute(arguments)
      puts "#{command} #{arguments}" if self.class.verbose
      `#{command} #{arguments}`
    end
  end
end
